package com.youdao.yjson;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.json.JSONArray;
import org.json.JSONObject;

/**
 * 
 * @author Yafei
 * 相关wiki介绍:
 * http://luna.corp.youdao.com/index.php?title=AndroidTool/YDJson
 */

public class YJson {

    private static final String TAG = YJson.class.getSimpleName();

    /**
     * 从一个json获取一个T对象并返回T,如一个用户的基本信息
     * @param jsonString
     * @param cls
     * @return
     */
    public static <T> T getObj(String jsonString, Class<T> cls) {
        T t = null;
        try {
            Gson gson = new Gson();
            t = gson.fromJson(jsonString, cls);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return t;
    }
    
    /**
     * 将一个JsonObject转成对应T类别的Object
     * @param jsonObject
     * @param cls
     * @return
     */
    public static <T> T getObj(JSONObject jsonObject, Class<T> cls) {
        T t = null;
        if (jsonObject == null){
        	return null;
        }
        try {
            Gson gson = new Gson();
            t = gson.fromJson(jsonObject.toString(), cls);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return t;
    }
    
    /**
     * 将一个JsonString转成对应T类别的Object泛型
     * @param jsonObject
     * @param cls
     * @return
     */
    public static <T> T getObj(String jsonString, TypeToken<T> token) {
        try {
            Gson gson = new Gson();
            return gson.fromJson(jsonString, token.getType());
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }
    /**
     * 从一个json获取一个List<T>对象并返回,如多个用户的基本信息
     * @param jsonString
     * @param cls
     * @return
     */
    public static <T> List<T> getList(JSONArray jsonArray, Class<T> cls) {
        List<T> list = null;
        try {
            Gson gson = new Gson();
            list = gson.fromJson(jsonArray.toString(), new TypeToken<List<T>>() {
            }.getType());
        } catch (Exception e) {
            e.printStackTrace();
        }
        return list;
    }
    
    /**
     * 从一个json获取一个List<T>对象并返回,如多个用户的基本信息
     * @param jsonString
     * @param cls
     * @return
     */
    public static <T> List<T> getList(String jsonString, Class<T[]> cls) {
        List<T> list = null;
        try {
            T[] arr = new Gson().fromJson(jsonString, cls);
            list = Arrays.asList(arr);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return list;
    }
    
    /**
     * 将一个Obj转成String
     * @param jsonString
     * @param cls
     * @return
     */
    public static <T> String getString(T json, Class<T> cls) {
        String jsonString = null;
        if (json == null){
        	return null;
        }
    	try {
            Gson gson = new Gson();
            jsonString = gson.toJson(json, cls);
            
        } catch (Exception e) {
            e.printStackTrace();
        }
        return jsonString;
    }
    
    /**
     * 将一个OBJ的List转成JSON
     * @param jsonString
     * @param cls
     * @return
     */
    public static <T> String getString(List<T> list, Class<T> cls) {
    	String jsonString = null;
    	if (list == null){
    		return null;
    	}
        try {
            Gson gson = new Gson();
            jsonString = gson.toJson(list, new TypeToken<List<T>>() {
            }.getType());
            return jsonString;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }
    
    /**
     * 降一个Obj转换成一个JSONObject 
     * @param json
     * @param cls
     * @return
     */
    public static <T> JSONObject getJSObj(T json, Class<T> cls) {
        String jsonString = null;
        JSONObject jsonObject = null;
    	try {
            Gson gson = new Gson();
            jsonString = gson.toJson(json, cls);
            jsonObject = new JSONObject(jsonString);
            return jsonObject;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }
    
    /**
     * 将一个list转换成JSONArray
     * @param list
     * @param cls
     * @return
     */
    public static <T> JSONArray getJSArray(List<T> list, Class<T> cls) {
    	String jsonString = null;
    	JSONArray jsonArray = null;
        try {
            Gson gson = new Gson();
            jsonString = gson.toJson(list, new TypeToken<List<T>>() {
            }.getType());
            jsonArray = new JSONArray(jsonString);
            return jsonArray;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

}
